@@ -26,6 +26,6 @@ const docdef* document_factory::get_docdef(const qname &docname) const {
   return it == doctype_map_.end() ? 0 : &it->second;
 }
 
-bool aka2::document_of(const std::string &tagname, const aka2::document &i) {
+bool aka2::document_of(const aka2::document &i, const std::string &tagname) {
   return aka2::qname(tagname) == i.get_name();
 }
