@@ -30,16 +30,17 @@ namespace aka2 {
     ptrmember_id,
     enclose_id,
     disclose_id,
-    any_id
+    any_id,
+    fixed_id
   };
 
   struct attribute_types;
-  class typeinfo;
+  class qname;
   /** Element */
   struct element_op {
     virtual ~element_op() {}
     virtual schematype_id get_schematype() const = 0;
-    virtual const typeinfo& get_typeinfo() const = 0;
+    virtual const qname& get_typename() const = 0;
     virtual void* create() const = 0;
     virtual void destroy(void *) const = 0;
     virtual bool equals(const void *lhs, const void *rhs) const = 0;
